ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind {
Show 14 variants NotFound, PermissionDenied, AlreadyExists, WouldBlock, InvalidInput, InvalidData, TimedOut, WriteZero, Interrupted, Unsupported, UnexpectedEof, OutOfMemory, TooBig, Other,
}
An enum providing a rough classification of errors.

The variants of this type partly resemble those of std::io::Error, because these are the most common sources of error that the crate concerns itself with.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotFound

An entity was not found, often a file.



PermissionDenied

The operation lacked the necessary privileges to complete.



AlreadyExists

An entity already exists, often a file.



WouldBlock

The operation needs to block to complete, but the blocking operation was requested to not occur.



InvalidInput

A parameter was incorrect.



InvalidData

Data not valid for the operation were encountered.



TimedOut

The I/O operation’s timeout expired, causing it to be canceled.



WriteZero

An error returned when an operation could not be completed because a call to write returned Ok(0).



Interrupted

This operation was interrupted.

Interrupted operations can typically be retried.



Unsupported

This operation is unsupported on this platform.



UnexpectedEof

An error returned when an operation could not be completed because an “end of file” was reached prematurely.



OutOfMemory

An operation could not be completed, because it failed to allocate enough memory.



TooBig

An argument exceeded a size limit imposed by the kernel.

Corresponds to E2BIG from the underlying syscall. For BPF map operations such as MapCore::update this typically means the map has reached its max_entries limit. The same code can also indicate that a BPF program is too large to load.



Other

A custom error that does not fall under any other I/O error kind.