MapType

Enum MapType 

#[non_exhaustive]
#[repr(u32)]
pub enum MapType {
Show 34 variants Unspec = 0, Hash = 1, Array = 2, ProgArray = 3, PerfEventArray = 4, PercpuHash = 5, PercpuArray = 6, StackTrace = 7, CgroupArray = 8, LruHash = 9, LruPercpuHash = 10, LpmTrie = 11, ArrayOfMaps = 12, HashOfMaps = 13, Devmap = 14, Sockmap = 15, Cpumap = 16, Xskmap = 17, Sockhash = 18, CgroupStorage = 19, CGrpStorage = 32, ReuseportSockarray = 20, PercpuCgroupStorage = 21, Queue = 22, Stack = 23, SkStorage = 24, DevmapHash = 25, StructOps = 26, RingBuf = 27, InodeStorage = 28, TaskStorage = 29, BloomFilter = 30, UserRingBuf = 31, Unknown = 4_294_967_295,
}
Type of a Map. Maps to enum bpf_map_type in kernel uapi.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspec = 0

An unspecified map type.



Hash = 1

A general purpose Hash map storage type.

Refer the kernel documentation for more details.



Array = 2

An Array map storage type.

Refer the kernel documentation for more details.



ProgArray = 3

A program array map which holds only the file descriptors to other eBPF programs. Used for tail-calls.

Refer documentation for more details.



PerfEventArray = 4

An array map which holds only the file descriptors to perf events.

Refer documentation for more details.



PercpuHash = 5

A Hash map with per CPU storage.

Refer the kernel documentation for more details.



PercpuArray = 6

An Array map with per CPU storage.

Refer the kernel documentation for more details.



StackTrace = 7



CgroupArray = 8



LruHash = 9

A Hash map with least recently used (LRU) eviction policy.

Refer the kernel documentation for more details.



LruPercpuHash = 10

A Hash map with least recently used (LRU) eviction policy with per CPU storage.

Refer the kernel documentation for more details.



LpmTrie = 11

A Longest Prefix Match (LPM) algorithm based map.

Refer the kernel documentation for more details.



ArrayOfMaps = 12

A map in map storage. One level of nesting is supported, where an outer map contains instances of a single type of inner map.

Refer the kernel documentation for more details.



HashOfMaps = 13

A map in map storage. One level of nesting is supported, where an outer map contains instances of a single type of inner map.

Refer the kernel documentation for more details.



Devmap = 14

An array map that uses the key as the index to lookup a reference to a net device. Primarily used for XDP BPF Helper.

Refer the kernel documentation for more details.



Sockmap = 15

An array map holds references to a socket descriptor.

Refer the kernel documentation for more details.



Cpumap = 16

A map that redirects raw XDP frames to another CPU.

Refer the kernel documentation for more details.



Xskmap = 17

A map that redirects raw XDP frames to AF_XDP sockets (XSKs), a new type of address family in the kernel that allows redirection of frames from a driver to user space without having to traverse the full network stack.

Refer the kernel documentation for more details.



Sockhash = 18

A Hash map that holds references to sockets via their socket descriptor.

Refer the kernel documentation for more details.



CgroupStorage = 19

Deprecated. Use CGrpStorage instead.

A Local storage for cgroups. Only available with CONFIG_CGROUP_BPF and to programs that attach to cgroups. Refer the kernel documentation for more details.



CGrpStorage = 32

A Local storage for cgroups. Only available with CONFIG_CGROUPS.

Refer the kernel documentation for more details. See also Difference between cgrp_storage and cgroup_storage



ReuseportSockarray = 20

A map that holds references to sockets with SO_REUSEPORT option set.

Refer documentation for more details.



PercpuCgroupStorage = 21

A per-CPU variant of BPF_MAP_TYPE_CGROUP_STORAGE.

Refer documentation for more details.



Queue = 22

A FIFO storage.

Refer the kernel documentation for more details.



Stack = 23

A LIFO storage.

Refer the kernel documentation for more details.



SkStorage = 24

A socket-local storage.

Refer the kernel documentation for more details.



DevmapHash = 25

A Hash map that uses the key as the index to lookup a reference to a net device. Primarily used for XDP BPF Helper.

Refer the kernel documentation for more details.



StructOps = 26

A specialized map that act as implementations of “struct ops” structures defined in the kernel.

Refer documentation for more details.



RingBuf = 27

A ring buffer map to efficiently send large amount of data.

Refer documentation for more details.



InodeStorage = 28

A storage map that holds data keyed on inodes.

Refer documentation for more details.



TaskStorage = 29

A storage map that holds data keyed on tasks.

Refer documentation for more details.



BloomFilter = 30

Bloom filters are a space-efficient probabilistic data structure used to quickly test whether an element exists in a set. In a bloom filter, false positives are possible whereas false negatives are not.

Refer the kernel documentation for more details.



UserRingBuf = 31



Unknown = 4_294_967_295

We choose to specify our own “unknown” type here b/c it’s really up to the kernel to decide if it wants to reject the map. If it accepts it, it just means whoever using this library is a bit out of date.

Implementations

Source

impl MapType

pub fn is_percpu(&self) -> bool

Returns if the map is of one of the per-cpu types.

pub fn is_hash_map(&self) -> bool

Returns if the map is of one of the hashmap types.

pub fn is_bloom_filter(&self) -> bool

Returns if the map is of bloom filter type

pub fn is_supported(&self) -> Result<bool>

Detects if host kernel supports this BPF map type.

Make sure the process has required set of CAP_* permissions (or runs as root) when performing feature checking.