ProgramType

Enum ProgramType 

#[non_exhaustive]
#[repr(u32)]
pub enum ProgramType {
Show 34 variants Unspec = 0, SocketFilter = 1, Kprobe = 2, SchedCls = 3, SchedAct = 4, Tracepoint = 5, Xdp = 6, PerfEvent = 7, CgroupSkb = 8, CgroupSock = 9, LwtIn = 10, LwtOut = 11, LwtXmit = 12, SockOps = 13, SkSkb = 14, CgroupDevice = 15, SkMsg = 16, RawTracepoint = 17, CgroupSockAddr = 18, LwtSeg6local = 19, LircMode2 = 20, SkReuseport = 21, FlowDissector = 22, CgroupSysctl = 23, RawTracepointWritable = 24, CgroupSockopt = 25, Tracing = 26, StructOps = 27, Ext = 28, Lsm = 29, SkLookup = 30, Syscall = 31, Netfilter = 32, Unknown = 4_294_967_295,
}
Type of a Program. Maps to enum bpf_prog_type in kernel uapi.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspec = 0



SocketFilter = 1



Kprobe = 2



SchedCls = 3



SchedAct = 4



Tracepoint = 5



Xdp = 6



PerfEvent = 7



CgroupSkb = 8



CgroupSock = 9



LwtIn = 10



LwtOut = 11



LwtXmit = 12



SockOps = 13



SkSkb = 14



CgroupDevice = 15



SkMsg = 16



RawTracepoint = 17



CgroupSockAddr = 18



LwtSeg6local = 19



LircMode2 = 20



SkReuseport = 21



FlowDissector = 22



CgroupSysctl = 23



RawTracepointWritable = 24



CgroupSockopt = 25



Tracing = 26



StructOps = 27



Ext = 28



Lsm = 29



SkLookup = 30



Syscall = 31



Netfilter = 32



Unknown = 4_294_967_295

Implementations

Source

impl ProgramType

pub fn is_supported(&self) -> Result<bool>

Detects if host kernel supports this BPF program type

Make sure the process has required set of CAP_* permissions (or runs as root) when performing feature checking.

pub fn is_helper_supported(&self, helper_id: bpf_func_id) -> Result<bool>

Detects if host kernel supports the use of a given BPF helper from this BPF program type.

  • helper_id - BPF helper ID (enum bpf_func_id) to check support for

Make sure the process has required set of CAP_* permissions (or runs as root) when performing feature checking.